# FeeMatrixRequest

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**internal_user_identifier** | **str** | Max length 100 characters | [optional] 
**internal_user_name** | **str** | Max length 100 characters | [optional] 
**major_paa_fee_traffic_sensitive** | **float** |  | 
**major_work_permit_fee_traffic_sensitive** | **float** |  | 
**standard_works_permit_fee_traffic_sensitive** | **float** |  | 
**minor_works_permit_fee_traffic_sensitive** | **float** |  | 
**immediate_works_permit_fee_traffic_sensitive** | **float** |  | 
**permit_variation_fee_traffic_sensitive** | **float** |  | 
**major_paa_fee_non_traffic_sensitive** | **float** |  | 
**major_work_permit_fee_non_traffic_sensitive** | **float** |  | 
**standard_works_permit_fee_non_traffic_sensitive** | **float** |  | 
**minor_works_permit_fee_non_traffic_sensitive** | **float** |  | 
**immediate_works_permit_fee_non_traffic_sensitive** | **float** |  | 
**permit_variation_fee_non_traffic_sensitive** | **float** |  | 
**discount_guidance** | **str** | Max length 500 characters | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

